@@ -1,5 +1,5 @@
 #include <RGtk2/gobject.h>
-#include "RGtk2/atk.h"
+#include <RGtk2/atk.h>
 
 #include "atkFuncs.h"
 
